@@ -28,7 +28,7 @@ class NomitallSession(requests.Session):
                 elif resp.status_code == 403:
                     self.logger.error(f"Check user permissions\n\t\t {reply_data}")
                 else:
-                    self.logger.error(f"Error from Nomitall: {reply_data['message']}")
+                    self.logger.error(f"Error from Nomitall: {reply_data}")
             except json.JSONDecodeError:
                 self.logger.error(
                     f"Error {resp.status_code} while communicating with nomitall : {resp.text}"
